Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(572)

Unified Diff: lib/runtime/dart_runtime.js

Issue 1011153002: js: fix core.Object, output order, static const fields (Closed) Base URL: git@github.com:dart-lang/dev_compiler.git@master
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | lib/src/codegen/js_codegen.dart » ('j') | lib/src/codegen/js_codegen.dart » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/runtime/dart_runtime.js
diff --git a/lib/runtime/dart_runtime.js b/lib/runtime/dart_runtime.js
index 8d602e0430e8b10a5211cbd037152fe3eebaed77..39c042368dfdaf4d9e2d036efb4772e9b05dc7e6 100644
--- a/lib/runtime/dart_runtime.js
+++ b/lib/runtime/dart_runtime.js
@@ -200,8 +200,8 @@ var dart;
// Conceptually this is: `class Mixin extends base {}`
function Mixin() {
// TODO(jmesserly): since we're using initializers and not constructors,
- // we can just skip directly to dart.Object.
- dart.Object.apply(this, arguments);
+ // we can just skip directly to core.Object.
+ core.Object.apply(this, arguments);
}
Mixin.__proto__ = base;
Mixin.prototype = Object.create(base.prototype);
@@ -341,7 +341,7 @@ var dart;
// TODO(jmesserly): we'll need to rethink this once the ES6 spec and V8
// settles. See <https://github.com/dart-lang/dart-dev-compiler/issues/51>.
// Performance of this pattern is likely to be bad.
- dart.Object = function Object() {
+ core.Object = function Object() {
// Get the class name for this instance.
var name = this.constructor.name;
// Call the default constructor.
@@ -350,8 +350,8 @@ var dart;
if (init) result = init.apply(this, arguments);
return result === void 0 ? this : result;
};
- // The initializer for dart.Object
- dart.Object.prototype.Object = function() {};
- dart.Object.prototype.constructor = dart.Object;
+ // The initializer for Object
+ core.Object.prototype.Object = function() {};
+ core.Object.prototype.constructor = core.Object;
})(dart || (dart = {}));
« no previous file with comments | « no previous file | lib/src/codegen/js_codegen.dart » ('j') | lib/src/codegen/js_codegen.dart » ('J')

Powered by Google App Engine
This is Rietveld 408576698